# -*- coding: utf-8 -*-
"""
Scores the readability of a text and output a variety of metrics including: Flesch-Kincaid Grade Level, Gunning Fog, ARI, Dale Chall, SMOG, and more
"""
__title__ = 'py-readabilitiy-metrics'
__version__ = '1.4.5'
__author__ = 'Carmine DiMascio'
__license__ = 'MIT'
__copyright__ = 'Copyright 2019 Carmine DiMascio'

from .readability import Readability
